---
title: 하위상점은 어떻게 설정할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 하위상점 관리 기능 이용방법
  description: >-
    하위상점 기능을 소개하고 관리자콘솔에서 설정하는 방법을 안내드립니다. 하위상점 추가 및 채널 설정방법, 연동시 참고사항까지 자세한 정보를
    확인해보세요.
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 'Agent '
  - 티어코드
  - 하위상점기능
  - 하위상점
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="하위상점 기능을 소개하고 관리자콘솔에서 설정하는 방법을 안내드립니다." title="" />

### **하위상점이란?**

- 포트원 관리자콘솔에서 회원가입을 하면 기본적으로 생성되는 계정은 상위상점입니다.
- 만약 상위상점에서 관리하는 상점이 있거나, 상위상점의 하위로 연계된 상점이 있을 경우 상위상점에서 관리하는 \[대표상점] 외 상점을 추가할 수 있습니다.
- 하위상점은 티어코드(tier code)로 구분할 수 있으며 이를 기준으로 결제 연동시에 분리하실 수 있습다. (하위상점에 대해 3자리 고유코드와 지점명 지정 가능)

### **하위상점 추가 및 채널 설정방법**

1. **포트원 관리자콘솔 로그인**

<Indent level="1">

- 아직 한번도 회원가입하신 적이 없을 경우 새롭게 회원가입을 하신 후 로그인해주시기 바랍니다.
- 또한 이미 회원가입이 되어있을 경우 로그인하신 계정이 Owner 권한의 계정인지 확인해주시기 바랍니다.

</Indent>



##### 2. **하위상점의 PG상점정보 설정**

<Indent level="1">

- 설정 > 하위 상점 관리 > 하위 상점 선택 > 정보 수정 클릭 후 원하는 PG사의 결제채널을 설정합니다.

</Indent>





<Callout title="채널 설정방법 보러가기 ↗" icon="" />

##### 3. **하위상점 추가**

<Indent level="1">

- 설정 > 하위 상점 관리 > + 하위상점 추가를 클릭합니다.

</Indent>



<Indent level="1">

- 사용할 결제채널 선택 에서 앞서 설정한 상점정보를 선택합니다.
- 상점명, 결제채널,티어코드는 필수값이며, 그 외는 선택항목입니다.

</Indent>



<Callout title="결제알림(Webhook)은 대표 상점과 동일하게 설정할게요" content="- 대표상점 계정에 설정된 웹훅 URL 과 동일하게 설정하고 싶으시다면 체크해주세요!
- 결제연동 > 실 연동관리 > 대표상점의 웹훅(Endpoint URL)을 먼저 저장해주셔야 합니다." icon="💡" />

4\. **최종 확인**

<Indent level="1">

- 설정 > 하위 상점 관리 메뉴에서 설정한 하위상점을 선택 후 실 결제 채널이 올바르게 설정되었는지 확인합니다.

</Indent>



### **연동시 참고사항**

- Agent 권한의 경우, IMP.init(고객사식별코드) 로 결제요청하는 방식이 아닌 하위몰별로 결제요청시 스크립트 단에서는 다음과 같이 Tier를 구분하여 호출하실 수 있습니다.
- IMP.agency(고객사식별코드, Tier(고유)코드 3자리)\
  예시) IMP.agency('imp12345678', '001')

<Callout content="REST API호출시에는 '**Header**'에 Tier정보를 같이 보내야 해당 Tier에 대한 접근이 가능합니다.

(예시)
`&quot;Tier&quot; : &quot;티어코드 3자리&quot;`" title="꼭 기억해주세요!" icon="❗" />
